import { Component, OnInit, ViewChild } from '@angular/core';
import { Observable, Subject } from 'rxjs';
import { DataStateChangeEventArgs, DataResult, DataSourceChangedEventArgs, EditSettingsModel, PageSettingsModel, FailureEventArgs, Grid } from '@syncfusion/ej2-grids';
import { OspiServiceProxy, DtoNajavaEdit, ListResultDtoOfDtoNajavaEdit } from 'src/shared/service-proxies/ospi-proxies';
import { ToolbarModel } from '@syncfusion/ej2-navigations';
import { Dialog } from '@syncfusion/ej2-popups';
import { GridComponent } from '@syncfusion/ej2-angular-grids';

@Component({
  selector: 'app-najave',
  templateUrl: './najave.component.html',
  styleUrls: ['./najave.component.css']
})
export class NajaveComponent implements OnInit {

  @ViewChild('grid') private grid: GridComponent;

  public searchValue: string = "";
  public data: Subject<Object>;
  public firma: DtoNajavaEdit;
  public state: DataStateChangeEventArgs;
  public toolbar: string[];
  public editSettings: EditSettingsModel;
  public editParams: Object;
  public pageSettings: PageSettingsModel;

  constructor(private ospiService: OspiServiceProxy) {
    this.data = new Subject<Object>();
   }
  
  private getData(id: number): void {
    if (!id) id = 0;

    this.ospiService.getNajaveByObratovalnicaID(id)
        .subscribe((x : ListResultDtoOfDtoNajavaEdit) => {

          this.firma = x.items.length > 0 ? x.items[0] : new DtoNajavaEdit();

          if (x.items.length > 0) { 
            this.data.next(
                (<DataResult>{
                  result : x.items,
                  count : x.items.length 
                }));    
            }
            else {
              // this.data.next(null);
              this.data.next(
                (<DataResult>{
                  result : [],
                  count : 0 
                }));    
            }
         });
  }

  ngOnInit() {
    this.firma = new DtoNajavaEdit();
    this.editSettings = { allowEditing: true, allowAdding: true, allowDeleting: true, mode: 'Dialog' };
    this.toolbar = ['Edit', 'Update', 'Cancel'];

    this.editParams = { params: { popupHeight: '300px' }};
    this.pageSettings = { pageSize: 10, pageCount: 4 };
    let state = { skip: 0, take: 10 };
    this.getData(0);

    this.data.subscribe((x)=>{
      // console.log("sprememba:" + (<DtoNajavaEdit>(x.result[0])).opomba)
    });
  }

  onRefresh() {
    this.grid.refresh();
  }

  onSearch() {
    this.getData(Number.parseInt(this.searchValue));
  }

  public dataStateChange (state: DataStateChangeEventArgs): void {
    this.getData(Number.parseInt(this.searchValue));
  }

  public dataSourceChanged(state: DataSourceChangedEventArgs): void {
    if (state.action === 'add') {
        // Todo: this.dataService.addRecord(state).subscribe(() => state.endEdit());
    } else if (state.action === 'edit') {
        let newData = <DtoNajavaEdit>state.data;
        this.ospiService
          .putNajaveByinput(newData)
          .subscribe(() => {
            state.endEdit()
              }
              , (e) => {
                this.grid.closeEdit();
                alert(e)
                // state.endEdit()
              }
          );
    } else if (state.requestType === 'delete') {
        // Todo: this.dataService.deleteRecord(state).subscribe(() => state.endEdit());
    }
  }

  public actionBegin(args) {
     let b = 1;



  }

  public actionComplete(args) {
    let c = 1;
    // if ((args.requestType === 'beginEdit' || args.requestType === 'add')) {
    //     let dialog: Dialog = args.dialog;
    //     dialog.height = 400;
    //     // change the header of the dialog
    //     // dialog.header = args.requestType === 'beginEdit' ? 'Record of ' + args.rowData['CustomerID'] : 'New Customer';
    // }
  }

  public actionFailure (args: FailureEventArgs) {
      alert(args.error);
  }


}
